Module: SolidusShipstation::Spree::ShipmentDecorator::ClassMethods
- Defined in:
- app/decorators/models/solidus_shipstation/spree/shipment_decorator.rb
Instance Method Summary collapse
Instance Method Details
#between(from, to) ⇒ Object
20 21 22 23 24 25 26 27 |
# File 'app/decorators/models/solidus_shipstation/spree/shipment_decorator.rb', line 20 def between(from, to) ::Spree::Deprecation.warn " `Spree::Shipment.between` is deprecated and will be removed in a future version\n of solidus_shipstation. Please use `SolidusShipstation::Shipment::BetweenQuery.apply`.\n DEPRECATION\n\n SolidusShipstation::Shipment::BetweenQuery.apply(self, from: from, to: to)\nend\n" |
#exportable ⇒ Object
11 12 13 14 15 16 17 18 |
# File 'app/decorators/models/solidus_shipstation/spree/shipment_decorator.rb', line 11 def exportable ::Spree::Deprecation.warn " `Spree::Shipment.exportable` is deprecated and will be removed in a future version\n of solidus_shipstation. Please use `SolidusShipstation::Shipment::ExportableQuery.apply`.\n DEPRECATION\n\n SolidusShipstation::Shipment::ExportableQuery.apply(self)\nend\n" |